@@ -90,7 +90,7 @@ class modbus():
 				date+=function[2:]
 				date+=hex(int(position))[2].zfill(4)
 				date+=hex(int(data_len))[2].zfill(4)
-				nb=1+1+2+2+int(data_len)
+				nb=1+1+1+int(data_len)*2
 			elif function =="0x05":
 				date="%s%s%s"%(hex(slave)[2:].zfill(2),function[2:],hex(int(position))[2].zfill(4))
 				if int(data_len,16) ==0:
@@ -144,7 +144,7 @@ class modbus():
 					date+=self._crc_cher_(date)
 					
 					self._ser_.write(self._return_modbus_(date))
-					s=self._ser_.read(nb)
+					s=self._ser_.read(nb+2)
 					if s is not '':
 						return_data=s.encode('hex').upper()
 						fmt_data= True
